**Example 1: 接口测试**

接口测试

Input: 

```
tccli csip DescribeCVMAssetInfo --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "Data": {
            "AccountNum": 0,
            "AssetId": "",
            "AssetName": "",
            "AssetType": "",
            "CWPStatus": 0,
            "DatabaseNum": 0,
            "EnvironmentVariableNum": 0,
            "JarPackageNum": 0,
            "KernelModuleNum": 0,
            "Os": "",
            "PortNum": 0,
            "PrivateIp": "",
            "ProcessNum": 0,
            "ProtectLevel": "",
            "ProtectedDay": 0,
            "PublicIp": "",
            "Region": "",
            "ScheduledTaskNum": 0,
            "ServiceNum": 0,
            "SoftApplicationNum": 0,
            "StartServiceNum": 0,
            "SurplusProtectDay": 0,
            "SystemInstallationPackageNum": 0,
            "Tag": null,
            "VpcId": "",
            "VpcName": "",
            "WebApplicationNum": 0,
            "WebFrameworkNum": 0,
            "WebSiteNum": 0
        },
        "RequestId": "41351849-7623-4356-866d-9e7920b875fa"
    }
}
```

